@@ -5,6 +5,7 @@ import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
 import java.util.ArrayList;
+import java.util.LinkedList;
 
 import miage.Format;
 
@@ -15,6 +16,8 @@ import miage.Format;
  */
 public class SqlProvider {
 
+	private static ArrayList<String> ALFic = new ArrayList<String>();
+	public static String DossierAct = null;
 	/**
 	 * Excute une requete de mise  jour
 	 * @param requete la requete  excuter
@@ -125,7 +128,7 @@ public class SqlProvider {
 	}
 
 	/**
-	 * Batch de suppression des table
+	 * Batch de suppression des tables
 	 */
 	protected static void deleteTable() {
 		SqlProvider.deleteEtoile("fichier");
@@ -178,6 +181,11 @@ public class SqlProvider {
 		String requete = "DELETE FROM dossier WHERE path = '" + path + "'";
 		return update(requete);
 	}
+	
+	public static int DeleteFromDossierId (int id) {
+		String requete = "DELETE FROM dossier WHERE ID = " + id ;
+		return update(requete);
+	}
 
 	/**
 	 *
@@ -190,11 +198,29 @@ public class SqlProvider {
 		return Connexion.resultsetUnEntier(id);
 	}
 	
+	
 	public static String getDossierNom(int id) {
 		String requete = "SELECT path FROM dossier WHERE id = " + id + "";
 		ResultSet nom = select(requete);
 		return Connexion.resultsetUneChaine(nom);
 	}
+	
+	public static ArrayList<String> getDossiersNoms() {
+		ArrayList<String> Arr = new ArrayList<String>();
+		String requete = "SELECT path FROM dossier";
+		try{
+			ResultSet Rs = select(requete);
+			while (Rs.next()) {
+			    Arr.add(Rs.getString(1));
+			}
+		}
+		catch (Exception exc){
+			System.out.println(exc);
+		}
+		
+		return Arr;
+
+	}
 
 
 	// TABLE ALBUM
@@ -442,9 +468,8 @@ public class SqlProvider {
 
 		colonnes += "comment, bitrate, taille, duree";
 		valeurs += "'" + comment + "', " + bitrate + ", " + taille + ", " + duree;
-
+		
 		String requete = "INSERT INTO fichier (" +  colonnes + ") VALUES (" + valeurs + ")";
-
 		return update(requete);
 	}
 
@@ -517,7 +542,65 @@ public class SqlProvider {
 		ResultSet id = select(requete);
 		return Connexion.resultsetUnEntier(id);
 	}
+	
+	/**
+	 * Modif MIAGE 2008.
+	 * @param path
+	 * @return
+	 */
+	public static boolean FichierExist(String path){
+		int i = path.lastIndexOf(File.separatorChar);
+		String dossier = path.substring(0, i);
+		String fichier = path.substring(i+1);
+		if (DossierAct==null || !DossierAct.equals(dossier)){
+			ALFic.clear();
+			DossierAct = dossier;
+			int IdDossier = SqlProvider.getDossierID(Format.nameDoubleQuotes(dossier));
+			if (IdDossier !=-1){
+				String requete = "SELECT nom FROM fichier WHERE id_dossier = " + IdDossier;
+				try{
+					ResultSet Rs = select(requete);
+					while (Rs.next()) {
+					    ALFic.add(Rs.getString(1));
+					}
+				}
+				catch (Exception exc){
+					System.out.println(exc);
+				}
+			}
+		}
+		if (ALFic.contains(fichier)) return true;
 
+		return false;
+	}
+	
+	public static ArrayList<String> FichierDossier(String dossier) {
+		ArrayList<String> AL = new ArrayList<String>();
+		int IdDossier = SqlProvider.getDossierID(Format.nameDoubleQuotes(dossier));
+		if (IdDossier !=-1){
+			String requete = "SELECT nom FROM fichier WHERE id_dossier = " + IdDossier;
+			try{
+				ResultSet Rs = select(requete);
+				while (Rs.next()) {
+				    AL.add(Rs.getString(1));
+				}
+			}
+			catch (Exception exc){
+				System.out.println(exc);
+			}
+		}
+		return AL;
+	}
+
+	/**
+	 * Supprime tous les fichiers correspondants  un dossier
+	 * @param IdDossier
+	 */
+	public static int supprimerFichierDossier (int IdDossier) {
+		String requete = "DELETE FROM fichier where id_dossier = " + IdDossier;
+		return update(requete);
+	}
+	
 	public static ArrayList<Object[]> getFichierPhysique(int id) {
 		String requete = "SELECT d.path, f.nom FROM fichier f JOIN dossier d ON f.id_dossier = d.id WHERE f.id = " + id;
 		ResultSet rst = select(requete);
